@@ -53,7 +53,7 @@ def example_data_download():
 		print('Cloning example datasets to the pyanthem package directory...')
 		try:
 			Repo.clone_from('https://github.com/nicthib/anthem_datasets.git',path)
-			print(f'Audio engine downloaded to {path}')
+			print(f'Example datasets downloaded to {path}')
 		except:
 			print('ERROR: git executable not present. Please visit https://git-scm.com/downloads to install.')
 	else:
@@ -126,7 +126,6 @@ class GUI(Tk):
 		'''
 		quits the GUI instance. currently, jupyter instances are kinda buggy
 		'''
-		print('new quit')
 		try:
 			get_ipython().__class__.__name__
 			self.destroy()
@@ -541,7 +540,7 @@ class GUI(Tk):
 		'''
 		if self.check_data_and_save_path():
 			fn = os.path.join(self.cfg['save_path'],self.cfg['file_out'])
-			cmd = 'ffmpeg -y -i {} -i {} -c:v copy -c:a aac {}'.format(fn+'.mp4',fn+'.wav',fn+'_AV.mp4')
+			cmd = 'ffmpeg -hide_banner -loglevel panic -y -i {} -i {} -c:v copy -c:a aac {}'.format(fn+'.mp4',fn+'.wav',fn+'_AV.mp4')
 			os.system(cmd)
 			if self.display:
 				self.status['text'] = f'Status: Video file w/ audio written to {self.cfg["save_path"]}'
